pynetdot
=======================

Python client for netdot <https://osl.uoregon.edu/redmine/projects/netdot> REST
API.

Netdot is an open source tool designed to help network administrators collect,
organize and maintain network documentation.

This client can query, edit, delete and create objects in a netdot installation
via it's generic REST API <https://myserver.mydomain.com/netdot/rest/>. It
exposes an interface similar to that of Django's models.
